# from invenio_access import authenticated_user
# from flask_principal import Permission
#
#
# def thesis_write_permission_factory(record=None, **kwargs):
#     return Permission(authenticated_user)

# TODO: dodělat až se budou řešit práva